@@ -26,6 +26,9 @@ pub use crate::core::{MiddlewareFn, MiddlewareNext, MiddlewareReturnValue};
 pub use app::testing_async as testing;
 pub use app::App;
 
+// Reexport tokio_util::sync::ReusableBoxFuture;
+pub use tokio_util::sync::ReusableBoxFuture;
+
 pub use server::*;
 
 #[cfg(feature = "hyper_server")]
